# mypy: disable_error_code = misc
import pxr.Ar as Ar
from pxr.UsdUtils.constantsGroup import ConstantsGroup as ConstantsGroup
from typing import ClassVar

class ARKitFileExtensionChecker(BaseRuleChecker):
    _allowedFileExtensions: ClassVar[tuple] = ...
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckZipFile(self, zipFile, packagePath): ...
    def GetDescription(self): ...

class ARKitLayerChecker(BaseRuleChecker):
    _allowedLayerFormatIds: ClassVar[tuple] = ...
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckLayer(self, layer): ...
    def GetDescription(self): ...

class ARKitMaterialBindingChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...

class ARKitPackageEncapsulationChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckDependencies(self, usdStage, layerDeps, assetDeps): ...
    def GetDescription(self): ...

class ARKitPrimTypeChecker(BaseRuleChecker):
    _allowedPrimTypeNames: ClassVar[tuple] = ...
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...

class ARKitRootLayerChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckStage(self, usdStage): ...
    def GetDescription(self): ...

class ARKitShaderChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...

class BaseRuleChecker:
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckDependencies(self, usdStage, layerDeps, assetDeps): ...
    def CheckDiagnostics(self, diagnostics): ...
    def CheckLayer(self, layer): ...
    def CheckPrim(self, prim): ...
    def CheckStage(self, usdStage): ...
    def CheckUnresolvedPaths(self, unresolvedPaths): ...
    def CheckZipFile(self, zipFile, packagePath): ...
    def GetErrors(self): ...
    def GetFailedChecks(self): ...
    def GetWarnings(self): ...
    def ResetCaches(self): ...
    def _AddError(self, msg): ...
    def _AddFailedCheck(self, msg): ...
    def _AddWarning(self, msg): ...
    def _Msg(self, msg): ...

class ByteAlignmentChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckZipFile(self, zipFile, packagePath): ...
    def GetDescription(self): ...

class ComplianceChecker:
    def __init__(self, arkit: bool = ..., skipARKitRootLayerCheck: bool = ..., rootPackageOnly: bool = ..., skipVariants: bool = ..., verbose: bool = ..., assetLevelChecks: bool = ...): ...
    def CheckCompliance(self, inputFile): ...
    def DumpAllRules(self): ...
    def DumpRules(self): ...
    def GetARKitRules(self, skipARKitRootLayerCheck: bool = ...): ...
    def GetBaseRules(self): ...
    def GetErrors(self): ...
    def GetFailedChecks(self): ...
    def GetRules(self, arkit: bool = ..., skipARKitRootLayerCheck: bool = ...): ...
    def GetWarnings(self): ...
    def _AddError(self, errMsg): ...
    def _AddWarning(self, errMsg): ...
    def _CheckLayer(self, layer): ...
    def _CheckPackage(self, packagePath): ...
    def _CheckPrim(self, prim): ...
    def _Msg(self, msg): ...
    def _TraverseRange(self, primRangeIt, isStageRoot): ...
    def _TraverseVariants(self, prim): ...

class CompressionChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckZipFile(self, zipFile, packagePath): ...
    def GetDescription(self): ...

class MaterialBindingAPIAppliedChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...

class MissingReferenceChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckDiagnostics(self, diagnostics): ...
    def CheckUnresolvedPaths(self, unresolvedPaths): ...
    def GetDescription(self): ...

class NodeTypes(ConstantsGroup):
    UsdPreviewSurface: ClassVar[str] = ...
    UsdPrimvarReader: ClassVar[str] = ...
    UsdTransform2d: ClassVar[str] = ...
    UsdUVTexture: ClassVar[str] = ...
    _all: ClassVar[tuple] = ...

class NormalMapTextureChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...
    def _GetInputValue(self, shader, inputName): ...
    def _GetShaderId(self, shader): ...
    def _TextureIs8Bit(self, asset): ...

class PrimEncapsulationChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...
    def ResetCaches(self): ...
    def _FindConnectableAncestor(self, prim): ...
    def _HasGprimAncestor(self, prim): ...

class ShaderProps(ConstantsGroup):
    Bias: ClassVar[str] = ...
    File: ClassVar[str] = ...
    Normal: ClassVar[str] = ...
    Scale: ClassVar[str] = ...
    SourceColorSpace: ClassVar[str] = ...
    _all: ClassVar[tuple] = ...

class SkelBindingAPIAppliedChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def GetDescription(self): ...

class StageMetadataChecker(BaseRuleChecker):
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckStage(self, usdStage): ...
    def GetDescription(self): ...

class TextureChecker(BaseRuleChecker):
    _basicUSDZImageFormats: ClassVar[tuple] = ...
    _extraUSDZ_OIIOImageFormats: ClassVar[str] = ...
    _unsupportedImageFormats: ClassVar[list] = ...
    def __init__(self, verbose, consumerLevelChecks, assetLevelChecks): ...
    def CheckPrim(self, prim): ...
    def CheckStage(self, usdStage): ...
    def GetDescription(self): ...
    def _CheckTexture(self, texAssetPath, inputPath): ...

def _IsPackageOrPackagedLayer(layer): ...